<?php
/**
 * galician language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Medúlio <medulio@ciberirmandade.org>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Rodrigo Rega <rodrigorega@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Editar esta páxina';
$lang['btn_source']            = 'Amosar a fonte da páxina';
$lang['btn_show']              = 'Amosar páxina';
$lang['btn_create']            = 'Crear esta páxina';
$lang['btn_search']            = 'Procurar';
$lang['btn_save']              = 'Gardar';
$lang['btn_preview']           = 'Previsualizar';
$lang['btn_top']               = 'Comezo da páxina';
$lang['btn_newer']             = '<< máis recente';
$lang['btn_older']             = 'menos recente >>';
$lang['btn_revs']              = 'Revisións antigas';
$lang['btn_recent']            = 'Trocos recentes';
$lang['btn_upload']            = 'Subir';
$lang['btn_cancel']            = 'Cancelar';
$lang['btn_index']             = 'Índice';
$lang['btn_secedit']           = 'Editar';
$lang['btn_login']             = 'Iniciar sesión';
$lang['btn_logout']            = 'Rematar sesión';
$lang['btn_admin']             = 'Administración';
$lang['btn_update']            = 'Actualizar';
$lang['btn_delete']            = 'Borrar';
$lang['btn_back']              = 'Atrás';
$lang['btn_backlink']          = 'Ligazóns con isto';
$lang['btn_subscribe']         = 'Avísame dos trocos na páxina';
$lang['btn_profile']           = 'Actualizar Perfil';
$lang['btn_reset']             = 'Reiniciar';
$lang['btn_resendpwd']         = 'Establecer novo contrasinal';
$lang['btn_draft']             = 'Editar borrador';
$lang['btn_recover']           = 'Recuperar borrador';
$lang['btn_draftdel']          = 'Eliminar borrador';
$lang['btn_revert']            = 'Restaurar';
$lang['btn_register']          = 'Rexístrate';
$lang['btn_apply']             = 'Aplicar';
$lang['btn_media']             = 'Xestor de Arquivos-Media';
$lang['loggedinas']            = 'Iniciaches sesión como:';
$lang['user']                  = 'Nome de Usuario';
$lang['pass']                  = 'Contrasinal';
$lang['newpass']               = 'Novo Contrasinal';
$lang['oldpass']               = 'Confirmar contrasinal actual';
$lang['passchk']               = 'de novo';
$lang['remember']              = 'Lémbrame';
$lang['fullname']              = 'Nome Completo';
$lang['email']                 = 'Correo-e';
$lang['profile']               = 'Perfil de Usuario';
$lang['badlogin']              = 'Sentímolo, mais o nome de usuario ou o contrasinal non son correctos.';
$lang['minoredit']             = 'Trocos Menores';
$lang['draftdate']             = 'Borrador gardado automaticamente en';
$lang['nosecedit']             = 'A páxina mudou entrementres, a información da sección estaba desfasada polo que se cargou a páxina completa no seu lugar.';
$lang['regmissing']            = 'Sentímolo, mais tes que cubrir todos os campos.';
$lang['reguexists']            = 'Sentímolo, mais xa existe un usuario con ese nome.';
$lang['regsuccess']            = 'O usuario foi creado e o contrasinal enviado por correo-e.';
$lang['regsuccess2']           = 'O usuario foi creado.';
$lang['regmailfail']           = 'Semella que houbo un erro ao tentar enviar o correo-e co contrasinal. Por favor, contacta co administrador!';
$lang['regbadmail']            = 'O enderezo de correo-e proporcionado semella incorrecto - se consideras que isto é un erro, contacta co administrador';
$lang['regbadpass']            = 'Os dous contrasinais inseridos non coinciden, por favor téntao de novo.';
$lang['regpwmail']             = 'O teu contrasinal do DokuWiki';
$lang['reghere']               = 'Aínda non tes unha conta? Crea a túa';
$lang['profna']                = 'Este wiki non permite modificacións dos perfís';
$lang['profnochange']          = 'Non hai trocos, nada que facer.';
$lang['profnoempty']           = 'Non se permite un nome ou un enderezo de correo-e baleiros.';
$lang['profchanged']           = 'Perfil de usuario actualizado correctamente.';
$lang['pwdforget']             = 'Esqueceches o teu contrasinal? Consegue un novo';
$lang['resendna']              = 'Este wiki non permite o reenvío de contrasinais.';
$lang['resendpwd']             = 'Establecer novo contrasinal para';
$lang['resendpwdmissing']      = 'Sentímolo, tes que cubrir todos os campos.';
$lang['resendpwdnouser']       = 'Sentímolo, non atopamos este usuario no noso banco de datos.';
$lang['resendpwdbadauth']      = 'Sentímolo, mais este código de autorización non é válido. Asegúrate de que usaches a ligazón completa de confirmación.';
$lang['resendpwdconfirm']      = 'Enviouse unha ligazón de confirmación por correo-e.';
$lang['resendpwdsuccess']      = 'O teu novo contrasinal foi enviado por correo-e.';
$lang['license']               = 'O contido deste wiki, agás onde se indique o contrario, ofrécese baixo da seguinte licenza:';
$lang['licenseok']             = 'Nota: Ao editares esta páxina estás a aceptar o licenciamento do contido baixo da seguinte licenza:';
$lang['searchmedia']           = 'Procurar nome de arquivo:';
$lang['searchmedia_in']        = 'Procurar en %s';
$lang['txt_upload']            = 'Escolle o arquivo para subir:';
$lang['txt_filename']          = 'Subir como (opcional):';
$lang['txt_overwrt']           = 'Sobrescribir arquivo existente';
$lang['maxuploadsize']         = 'Subida máxima %s por arquivo.';
$lang['lockedby']              = 'Bloqueado actualmente por:';
$lang['lockexpire']            = 'O bloqueo remata o:';
$lang['js']['willexpire']      = 'O teu bloqueo para editares esta páxina vai caducar nun minuto.\nPara de evitar conflitos, emprega o botón de previsualización para reiniciares o contador do tempo de bloqueo.';
$lang['js']['notsavedyet']     = 'Perderanse os trocos non gardados.
Está certo de quereres continuar?';
$lang['js']['searchmedia']     = 'Procurar ficheiros';
$lang['js']['keepopen']        = 'Manter a fiestra aberta na selección';
$lang['js']['hidedetails']     = 'Agochar Pormenores';
$lang['js']['mediatitle']      = 'Configuración de ligazón';
$lang['js']['mediadisplay']    = 'Tipo de ligazón';
$lang['js']['mediaalign']      = 'Aliñamento';
$lang['js']['mediasize']       = 'Tamaño de imaxe';
$lang['js']['mediatarget']     = 'Albo da ligazón';
$lang['js']['mediaclose']      = 'Fechar';
$lang['js']['mediainsert']     = 'Inserir';
$lang['js']['mediadisplayimg'] = 'Amosar a imaxe';
$lang['js']['mediadisplaylnk'] = 'Amosar só a ligazón';
$lang['js']['mediasmall']      = 'Versión reducida';
$lang['js']['mediamedium']     = 'Versión media';
$lang['js']['medialarge']      = 'Versión grande';
$lang['js']['mediaoriginal']   = 'Versión orixinal';
$lang['js']['medialnk']        = 'Ligazón para a páxina de pormenores';
$lang['js']['mediadirect']     = 'Ligazón directa para o orixinal';
$lang['js']['medianolnk']      = 'Sen ligazón';
$lang['js']['medianolink']     = 'Non ligar a imaxe';
$lang['js']['medialeft']       = 'Aliñar a imaxe á esquerda';
$lang['js']['mediaright']      = 'Aliñar a imaxe á dereita';
$lang['js']['mediacenter']     = 'Aliñar a iamxe ao medio';
$lang['js']['medianoalign']    = 'Non empregar aliñamento';
$lang['js']['nosmblinks']      = 'A ligazón aos compartidos do Windows só funciona no Microsoft Internet Explorer.
Sempre podes copiar e colar a ligazón.';
$lang['js']['linkwiz']         = 'Asistente de ligazóns';
$lang['js']['linkto']          = 'Ligazón para:';
$lang['js']['del_confirm']     = 'Estás certo de quereres eliminar os elementos seleccionados?';
$lang['js']['restore_confirm'] = 'Realmente desexas restaurar esta versión?';
$lang['js']['media_diff']      = 'Ver as diferencias:';
$lang['js']['media_diff_both'] = 'Cara a Cara';
$lang['js']['media_diff_opacity'] = 'Opacidade';
$lang['js']['media_diff_portions'] = 'Porcións';
$lang['js']['media_select']    = 'Selecciona arquivos...';
$lang['js']['media_upload_btn'] = 'Subir';
$lang['js']['media_done_btn']  = 'Feito';
$lang['js']['media_drop']      = 'Solta aquí os arquivos a subir';
$lang['js']['media_cancel']    = 'eliminar';
$lang['js']['media_overwrt']   = 'Sobreescribir os arquivos existentes';
$lang['rssfailed']             = 'Houbo un erro ao tentar obter esta corrente RSS: ';
$lang['nothingfound']          = 'Non se atopou nada.';
$lang['mediaselect']           = 'Arquivos-Media';
$lang['uploadsucc']            = 'Subida correcta';
$lang['uploadfail']            = 'Erra na subida. Pode que sexa un problema de permisos?';
$lang['uploadwrong']           = 'Subida denegada. Esta extensión de arquivo non está permitida!';
$lang['uploadexist']           = 'Xa existe o arquivo. Non se fixo nada.';
$lang['uploadbadcontent']      = 'O contido subido non concorda coa extensión do arquivo %s.';
$lang['uploadspam']            = 'A subida foi bloqueada pola lista negra de correo-lixo.';
$lang['uploadxss']             = 'A subida foi bloqueada por un posíbel contido malicioso.';
$lang['uploadsize']            = 'O arquivo subido é grande de máis. (máx. %s)';
$lang['deletesucc']            = 'O arquivo "%s" foi eliminado.';
$lang['deletefail']            = '"%s" non puido ser eliminado - comproba os permisos.';
$lang['mediainuse']            = 'O arquivo "%s" non foi eliminado - aínda está en uso.';
$lang['namespaces']            = 'Nomes de espazos';
$lang['mediafiles']            = 'Arquivos dispoñíbeis en';
$lang['accessdenied']          = 'Non tes permitido ver esta páxina.';
$lang['mediausage']            = 'Emprega a seguinte sintaxe para inserires unha referencia a este arquivo:';
$lang['mediaview']             = 'Ver arquivo orixinal';
$lang['mediaroot']             = 'raigaña';
$lang['mediaupload']           = 'Sube aquí un arquivo ao nome de espazo actual. Para creares sub-nomes de espazos deberás antepoñelos ao nome indicado en "Subir como" separados por dous puntos.';
$lang['mediaextchange']        = 'Extensión de arquivo mudada de .%s a .%s!';
$lang['reference']             = 'Referencias para';
$lang['ref_inuse']             = 'O arquivo non pode ser eliminado, xa que aínda está a ser usado polas seguintes páxinas:';
$lang['ref_hidden']            = 'Algunhas referencias están en páxinas para as cales non tes permisos de lectura';
$lang['hits']                  = 'Vistas';
$lang['quickhits']             = 'Nomes de páxinas coincidentes';
$lang['toc']                   = 'Táboa de Contidos';
$lang['current']               = 'actual';
$lang['yours']                 = 'A túa Versión';
$lang['diff']                  = 'Amosar diferenzas coa versión actual';
$lang['diff2']                 = 'Amosar diferenzas entre as revisións seleccionadas';
$lang['difflink']              = 'Enlazar a esta vista de comparación';
$lang['diff_type']             = 'Ver diferenzas:';
$lang['diff_inline']           = 'Por liña';
$lang['diff_side']             = 'Cara a Cara';
$lang['line']                  = 'Liña';
$lang['breadcrumb']            = 'Trazado:';
$lang['youarehere']            = 'Estás aquí:';
$lang['lastmod']               = 'Última modificación:';
$lang['by']                    = 'por';
$lang['deleted']               = 'eliminado';
$lang['created']               = 'creado';
$lang['restored']              = 'revisión antiga restaurada (%s)';
$lang['external_edit']         = 'edición externa';
$lang['summary']               = 'Resumo da edición';
$lang['noflash']               = 'Precísase o <a href="http://get.adobe.com/flashplayer">Extensión Adobe Flash</a> para amosar este contido.';
$lang['download']              = 'Descargar Retallo (Snippet)';
$lang['tools']                 = 'Ferramentas';
$lang['user_tools']            = 'Ferramentas de usuario';
$lang['site_tools']            = 'Ferramentas do sitio';
$lang['page_tools']            = 'Ferramentas de páxina';
$lang['skip_to_content']       = 'Pasar ao contido';
$lang['sidebar']               = 'Barra lateral';
$lang['mail_newpage']          = 'páxina engadida:';
$lang['mail_changed']          = 'páxina mudada:';
$lang['mail_subscribe_list']   = 'páxinas mudadas en nome de espazo:';
$lang['mail_new_user']         = 'Novo usuario:';
$lang['mail_upload']           = 'arquivo subido:';
$lang['changes_type']          = 'Ver cambios';
$lang['pages_changes']         = 'Páxinas';
$lang['media_changes']         = 'Arquivos-Media';
$lang['both_changes']          = 'Ambos, páxinas e arquivos-media';
$lang['qb_bold']               = 'Texto Resaltado';
$lang['qb_italic']             = 'Texto en Cursiva';
$lang['qb_underl']             = 'Texto Subliñado';
$lang['qb_code']               = 'Texto de Código';
$lang['qb_strike']             = 'Texto Riscado';
$lang['qb_h1']                 = 'Liña de Cabeceira de Nivel 1';
$lang['qb_h2']                 = 'Liña de Cabeceira de Nivel 2';
$lang['qb_h3']                 = 'Liña de Cabeceira de Nivel 3';
$lang['qb_h4']                 = 'Liña de Cabeceira de Nivel 4';
$lang['qb_h5']                 = 'Liña de Cabeceira de Nivel 5';
$lang['qb_h']                  = 'Liña de Cabeceira';
$lang['qb_hs']                 = 'Escoller Liña de Cabeceira';
$lang['qb_hplus']              = 'Liña de Cabeceira Máis Alta';
$lang['qb_hminus']             = 'Liña de Cabeceira Máis Baixa';
$lang['qb_hequal']             = 'Liña de Cabeceira ao Mesmo Nivel';
$lang['qb_link']               = 'Ligazón Interna';
$lang['qb_extlink']            = 'Ligazón Externa';
$lang['qb_hr']                 = 'Liña Horizontal';
$lang['qb_ol']                 = 'Elemento de Lista Ordenada';
$lang['qb_ul']                 = 'Elemento de Lista Desordenada';
$lang['qb_media']              = 'Engadir Imaxes e Outros Arquivos';
$lang['qb_sig']                = 'Inserir Sinatura';
$lang['qb_smileys']            = 'Risoños';
$lang['qb_chars']              = 'Caracteres Especiais';
$lang['upperns']               = 'choutar ao nome de espazo pai';
$lang['metaedit']              = 'Editar Metadatos';
$lang['metasaveerr']           = 'Non se puideron escribir os metadatos';
$lang['metasaveok']            = 'Metadatos gardados';
$lang['btn_img_backto']            = 'Volver a %s';
$lang['img_title']             = 'Título:';
$lang['img_caption']           = 'Lenda:';
$lang['img_date']              = 'Data:';
$lang['img_fname']             = 'Nome de arquivo:';
$lang['img_fsize']             = 'Tamaño:';
$lang['img_artist']            = 'Fotógrafo:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Formato:';
$lang['img_camera']            = 'Cámara:';
$lang['img_keywords']          = 'Verbas chave:';
$lang['img_width']             = 'Ancho:';
$lang['img_height']            = 'Alto:';
$lang['btn_mediaManager']           = 'Ver no xestor de arquivos-media';
$lang['subscr_subscribe_success'] = 'Engadido %s á lista de subscrición para %s';
$lang['subscr_subscribe_error'] = 'Erro ao tentar engadir %s á lista de subscrición para %s';
$lang['subscr_subscribe_noaddress'] = 'Non hai enderezos asociados co teu inicio de sesión, non é posíbel engadirte á lista de subscrición';
$lang['subscr_unsubscribe_success'] = 'Eliminado %s da lista de subscrición para %s';
$lang['subscr_unsubscribe_error'] = 'Erro ao tentar eliminar %s da lista de subscrición para %s';
$lang['subscr_already_subscribed'] = '%s xa está subscrito a %s';
$lang['subscr_not_subscribed'] = '%s non está subscrito a %s';
$lang['subscr_m_not_subscribed'] = 'Agora mesmo non estás subscrito á páxina ou nome de espazo actual';
$lang['subscr_m_new_header']   = 'Engadir subscrición';
$lang['subscr_m_current_header'] = 'Subscricións actuais';
$lang['subscr_m_unsubscribe']  = 'Desubscribir';
$lang['subscr_m_subscribe']    = 'Subscribir';
$lang['subscr_m_receive']      = 'Recibir';
$lang['subscr_style_every']    = 'correo-e en cada troco';
$lang['authtempfail']          = 'A autenticación de usuario non está dispoñible de xeito temporal. De persistir esta situación, por favor, informa ao Administrador do teu Wiki.';
$lang['i_chooselang']          = 'Escolle o teu idioma';
$lang['i_installer']           = 'Instalador do DokuWiki';
$lang['i_wikiname']            = 'Nome do Wiki';
$lang['i_enableacl']           = 'Activar ACL (recomendado)';
$lang['i_superuser']           = 'Super-usuario';
$lang['i_problems']            = 'O instalador atopou algúns problemas, que se amosan de seguido. Non poderás continuar até que os soluciones.';
$lang['i_modified']            = 'Por razóns de seguridade este script só funcionará cunha instalación nova e sen modificar do Dokuwiki.
                         Podes ou ben extraer de novo os arquivos dende o paquete descargado ou consultar as
                         <a href="https://www.dokuwiki.org/install">instruccións completas de instalación do Dokuwiki</a>';
$lang['i_funcna']              = 'A función <code>%s</code> do PHP non está dispoñíbel. Pode que o teu provedor de hospedaxe a desactivase por algún motivo?';
$lang['i_phpver']              = 'A túa versión <code>%s</code> do PHP é inferior á <code>%s</code> precisa. Debes actualizar a túa instalación do PHP.';
$lang['i_permfail']            = '<code>%s</code> non é escribíbel polo DokuWiki. Debes corrixir a configuración de permisos deste directorio!';
$lang['i_confexists']          = '<code>%s</code> xa existe';
$lang['i_writeerr']            = 'Non se puido crear <code>%s</code>. Terás de comprobar os permisos do directorio/arquivo e crear o ficheiro de xeito manual.';
$lang['i_badhash']             = 'dokuwiki.php irrecoñecíbel ou modificado (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - ilegal ou valor baleiro';
$lang['i_success']             = 'A configuración rematou correctamente. Agora podes eliminar o arquivo install.php. Continúa deica o
                        <a href="doku.php?id=wiki:welcome">teu novo DokuWiki</a>.';
$lang['i_failure']             = 'Houbo algúns erros ao tentar escribir os arquivos de configuración. Pode que precises solucionalos de xeito manual antes
                         de poderes empregar <a href="doku.php?id=wiki:welcome">o teu novo DokuWiki</a>.';
$lang['i_policy']              = 'Regras iniciais da ACL';
$lang['i_pol0']                = 'Wiki Aberto (lectura, escritura, subida de arquivos para todas as persoas)';
$lang['i_pol1']                = 'Wiki Público (lectura para todas as persoas, escritura e subida de arquivos para usuarios rexistrados)';
$lang['i_pol2']                = 'Wiki Fechado (lectura, escritura, subida de arquivos só para usuarios rexistrados)';
$lang['i_retry']               = 'Tentar de novo';
$lang['i_license']             = 'Por favor escolla a licenza para o contido:';
$lang['recent_global']         = 'Agora mesmo estás a ver os trocos no nome de espazo <b>%s</b>. Tamén podes <a href="%s">ver os trocos recentes no Wiki enteiro</a>.';
$lang['years']                 = 'hai %d anos';
$lang['months']                = 'hai %d meses';
$lang['weeks']                 = 'hai %d semanas';
$lang['days']                  = 'hai %d días';
$lang['hours']                 = 'hai %d horas';
$lang['minutes']               = 'hai %d minutos';
$lang['seconds']               = 'hai %d segundos';
$lang['wordblock']             = 'Non se gardaron os cambios porque conteñen texto bloqueado (spam).';
$lang['media_uploadtab']       = 'Subir';
$lang['media_searchtab']       = 'Buscar';
$lang['media_file']            = 'Arquivo';
$lang['media_viewtab']         = 'Ver';
$lang['media_edittab']         = 'Editar';
$lang['media_historytab']      = 'Histórico';
$lang['media_list_thumbs']     = 'Miniaturas';
$lang['media_list_rows']       = 'Filas';
$lang['media_sort_name']       = 'Nome';
$lang['media_sort_date']       = 'Data';
$lang['media_namespaces']      = 'Escolla espazo';
$lang['media_files']           = 'Arquivos en %s';
$lang['media_upload']          = 'Subir a %s';
$lang['media_search']          = 'Buscar en %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s en %s';
$lang['media_edit']            = 'Editar %s';
$lang['media_history']         = 'Historia de %s';
$lang['media_meta_edited']     = 'datos meta editados';
$lang['media_perm_read']       = 'Sentímolo, non tes permisos suficientes para ler arquivos.';
$lang['media_perm_upload']     = 'Sentímolo, non tes permisos suficientes para subir arquivos.';
$lang['media_update']          = 'Subir nova versión';
$lang['media_restore']         = 'Restaurar esta versión';
$lang['email_signature_text'] = 'Este correo foi xerado polo DokuWiki en
@DOKUWIKIURL@';
